"""Gen a tfidf model."""
from typing import List, Union
from sklearn.feature_extraction.text import TfidfVectorizer

from logzero import logger


# fmt: off
def gen_model(
        text: Union[str, List[str]],
        max_features: int = 1000,
) -> TfidfVectorizer:
    # fmt: on
    """Gen a tfidf model.

    Args:
        text: space delimited words/chinese chars/numbers
            or normal Chinese text: see token_pattern below
    Returns:
        TfidfVectorizer
    """
    # patt = re.compile(r"[一-龟]|\d+|[a-zA-Z]+")

    # model = TfidfVectorizer(token_pattern=r"(?u)\b\w+\b", max_features=max_features).fit(text)

    # TfidfVectorizer needs a list
    if isinstance(text, str):
        text = [text]

    try:
        model = TfidfVectorizer(
            token_pattern=r"[一-龟]|\d+|[a-zA-Z]+",
            max_features=max_features,
        ).fit(text)
    except Exception as e:
        logger.error(e)
        raise
        # raise SystemExit(1) from e

    return model



"""Translate english to chinese via a dict."""
from typing import List, Union

import copy
from fast_scores.word_tr import word_tr


# fmt: off
def en2zh(
        text: Union[str, List[List[str]]],
) -> List[str]:
    # fmt: on
    """Translate english to chinese via a dict.

    Args
        text: to translate, list of list of str

    Returns
        res: list of str
    """
    res = copy.deepcopy(text)
    if isinstance(text, str):
        res = [text.split()]

    # if res and isinstance(res[0], str):
        # res = [line.lower().split() for line in res]

    res = ["".join([word_tr(word) for word in line]) for line in res]

    return res
